@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import re
+import os
 
 from pptree import Node, print_tree
 from suite_py.lib.handler.aws_handler import Aws
@@ -49,7 +50,14 @@ class IP:
                         for ip in ips:
                             Node(ip, n_service)
 
-        if n_services.children:
+        if self._env == "staging" and os.path.isfile("./deploy/values/staging.yml"):
+            logger.info(
+                "This project has been migrated on k8s, command is no longer available."
+            )
+            logger.info(
+                "Guide on how to setup k8s: https://app.tettra.co/teams/prima-assicurazioni/pages/effettuare-operazioni-su-k8s"
+            )
+        elif n_services.children:
             print_tree(n_services, horizontal=True)
         else:
             logger.info(
